package
Version:
v0.0.0-...-e6a2bac
Opens a new window with list of versions in this module.
Published: Mar 17, 2025
License: MIT
Opens a new window with license information.
Imports: 4
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
Module of config things.
nolint:gochecknoglobals
DIProvider wrap di into provider.
Viper returns global Viper instance.
Core configuration.
Provider - wrap app config to provider.
SafeType returns config type, default config type: yaml.
returns yml if config type not supported.
nolint:goconst
type Defaults interface{}
Defaults is callback that allows to setup application before run.
Helium calls `defaults` handler at the end in `New` method.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.